Class: Fastlane::Actions::UploadTestdroidAction

Inherits:
Action
  • Object
show all
Defined in:
lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb

Class Method Summary collapse

Class Method Details

.authorsObject



16
17
18
# File 'lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb', line 16

def self.authors
  ["josepmc"]
end

.available_optionsObject



30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb', line 30

def self.available_options
  [
    FastlaneCore::ConfigItem.new(key: :api_key,
                            env_name: "TESTDROID_RUNNER_API_KEY",
                            description: "The API key used to connect to BitBar",
                            optional: false,
                            type: String),
    FastlaneCore::ConfigItem.new(key: :application_file,
                            env_name: "TESTDROID_RUNNER_APPLICATION_FILE",
                            description: "Either an IPA or APK containing the core application",
                            optional: false,
                            type: String),
    FastlaneCore::ConfigItem.new(key: :access_group,
                            env_name: "TESTDROID_RUNNER_ACCESS_GROUP",
                            description: "If present, will share uploaded files with the named access group",
                            optional: true,
                            type: String)
  ]
end

.descriptionObject



12
13
14
# File 'lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb', line 12

def self.description
  "Uploads a file to bitbar"
end

.detailsObject



25
26
27
28
# File 'lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb', line 25

def self.details
  # Optional:
  "Uploads a file to bitbar"
end

.is_supported?(platform) ⇒ Boolean

Returns:

  • (Boolean)


50
51
52
# File 'lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb', line 50

def self.is_supported?(platform)
  [:ios, :android].include?(platform)
end

.return_valueObject



20
21
22
23
# File 'lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb', line 20

def self.return_value
  # If your method provides a return value, you can describe here what it does
  "Returns the uploaded file id"
end

.run(params) ⇒ Object



7
8
9
10
# File 'lib/fastlane/plugin/testdroid_runner/actions/upload_testdroid_action.rb', line 7

def self.run(params)
  $stdout.sync = true
  Helper::UploadFile.run(params)
end